@@ -20,10 +20,13 @@
 #  pragma system_header
 #endif // no system header
 
+#include <cuda/std/__cccl/prologue.h>
+
 _LIBCUDACXX_BEGIN_NAMESPACE_STD
 
+_CCCL_EXEC_CHECK_DISABLE
 template <class _InputIterator, class _OutputIterator, class _Predicate, class _Tp>
-_LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX14 _OutputIterator replace_copy_if(
+_CCCL_API constexpr _OutputIterator replace_copy_if(
   _InputIterator __first, _InputIterator __last, _OutputIterator __result, _Predicate __pred, const _Tp& __new_value)
 {
   for (; __first != __last; ++__first, (void) ++__result)
@@ -42,4 +45,6 @@ _LIBCUDACXX_HIDE_FROM_ABI _CCCL_CONSTEXPR_CXX14 _OutputIterator replace_copy_if(
 
 _LIBCUDACXX_END_NAMESPACE_STD
 
+#include <cuda/std/__cccl/epilogue.h>
+
 #endif // _LIBCUDACXX___ALGORITHM_REPLACE_COPY_IF_H
