@@ -1,4 +1,6 @@
 """Functions for FIR filter design."""
+from __future__ import annotations
+
 import math
 
 from cupy.fft import fft, ifft
@@ -169,7 +171,6 @@ _firwin_kernel = cupy.ElementwiseKernel(
     }
     """,
     "_firwin_kernel",
-    options=("-std=c++11",),
     loop_prep="const double alpha { 0.5 * ( numtaps - 1 ) };",
 )
 
@@ -783,7 +784,7 @@ def _dhtm(mag):
     return recon
 
 
-def minimum_phase(h, method='homomorphic', n_fft=None):
+def minimum_phase(h, method='homomorphic', n_fft=None, half=True):
     """Convert a linear-phase FIR filter to minimum phase
 
     Parameters
@@ -808,6 +809,13 @@ def minimum_phase(h, method='homomorphic', n_fft=None):
         The number of points to use for the FFT. Should be at least a
         few times larger than the signal length (see Notes).
 
+    half : bool
+        If ``True``, create a filter that is half the length of the original, with a
+        magnitude spectrum that is the square root of the original. If ``False``,
+        create a filter that is the same length as the original, with a magnitude
+        spectrum that is designed to match the original (only supported when
+        ``method='homomorphic'``).
+
     Returns
     -------
     h_minimum : array
@@ -900,19 +908,20 @@ def minimum_phase(h, method='homomorphic', n_fft=None):
         # take 0.25*log(|H|**2) = 0.5*log(|H|)
         h_temp += 1e-7 * h_temp[h_temp > 0].min()  # don't let log blow up
         cupy.log(h_temp, out=h_temp)
-        h_temp *= 0.5
+        if half:
+            h_temp *= 0.5
         # IDFT
         h_temp = ifft(h_temp).real
         # multiply pointwise by the homomorphic filter
         # lmin[n] = 2u[n] - d[n]
         win = cupy.zeros(n_fft)
         win[0] = 1
-        stop = (len(h) + 1) // 2
+        stop = n_fft // 2
         win[1:stop] = 2
-        if len(h) % 2:
+        if n_fft % 2:
             win[stop] = 1
         h_temp *= win
         h_temp = ifft(cupy.exp(fft(h_temp)))
         h_minimum = h_temp.real
-    n_out = n_half + len(h) % 2
+    n_out = (n_half + len(h) % 2) if half else len(h)
     return h_minimum[:n_out]
